/*
 * Copyright 2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.language.nativeplatform.internal;

import java.util.List;

/**
 * An immutable snapshot of the preprocessor directives from a source or header file.
 */
public interface IncludeDirectives {
    List<Include> getQuotedIncludes();
    List<Include> getSystemIncludes();
    List<Include> getMacroIncludes();
    List<Include> getAll();
    List<Include> getIncludesOnly();

    List<Macro> getMacros();
    List<MacroFunction> getMacrosFunctions();

    /**
     * Returns a copy of these directives, with #import directives removed.
     */
    IncludeDirectives discardImports();
}
